@@ -1,18 +1,15 @@
-import itertools
 from typing import (
     TYPE_CHECKING,
-    Generator,
-    Iterator,
-    Sequence,
+    Iterable,
 )
 
-from .. import DocumentArray
+from docarray.array.memory import DocumentArrayInMemory
 
 if TYPE_CHECKING:
-    from ..document import Document
+    from docarray.document import Document
 
 
-class MatchArray(DocumentArray):
+class MatchArray(DocumentArrayInMemory):
     """
     :class:`MatchArray` inherits from :class:`DocumentArray`.
     It's a subset of Documents that represents the matches
@@ -24,12 +21,7 @@ class MatchArray(DocumentArray):
     def __init__(self, docs, reference_doc: 'Document'):
         self._ref_doc = reference_doc
         super().__init__(docs)
-        if (
-            isinstance(
-                docs, (DocumentArray, Sequence, Generator, Iterator, itertools.chain)
-            )
-            and self._ref_doc is not None
-        ):
+        if isinstance(docs, Iterable) and self._ref_doc is not None:
             for d in docs:
                 d.adjacency = self._ref_doc.adjacency + 1
 
