@@ -149,7 +149,7 @@ class PlotMixin:
         :param image_source: specify where the image comes from, can be ``uri`` or ``tensor``. empty tensor will fallback to uri
         :return: the path to the embeddings visualization info.
         """
-        from ...helper import random_port, __resources_path__
+        from docarray.helper import random_port, __resources_path__
 
         path = path or tempfile.mkdtemp()
         emb_fn = f'{title}.tsv'
@@ -432,7 +432,6 @@ class PlotMixin:
         import matplotlib.pyplot as plt
 
         img_per_row = ceil(sqrt(len(self)))
-        img_per_col = ceil(len(self) / img_per_row)
         img_size = int(canvas_size / img_per_row)
 
         if img_size < min_size:
@@ -440,6 +439,10 @@ class PlotMixin:
             img_size = min_size
             img_per_row = int(canvas_size / img_size)
 
+        if img_per_row == 0:
+            img_per_row = 1
+
+        img_per_col = ceil(len(self) / img_per_row)
         max_num_img = img_per_row * img_per_col
         sprite_img = np.zeros(
             [img_size * img_per_col, img_size * img_per_row, 3], dtype='uint8'
